pub struct BitVector {
pub size: Option<u64>,
pub bytes: Option<Vec<u8>>,
}Expand description
Compressed representation of a vector of bits. It occupies n/8 + O(1) bytes. Note: this is not a highly optimized data structure:
- since it is a proto message it requires its length to be stored.
- it has 2 fields, which require storing their own tag
- the
bytes_field requires storing its length, which theoretically could be derived fromsizefield value. If we eventually start caring about the size, we could encode BitVector directly as a field of typebyteswith delimiter of the form “01…1”.
Fields
size: Option<u64>Number of bits in the vector.
bytes: Option<Vec<u8>>Vector of bits encoded as bytes in big endian order.
Implementations